macro_rules! annotate {
($e:expr) => { ... };
}Expand description
Annotates an io::Error with the crate, file, and line number where the annotation has been performed.
macro_rules! annotate {
($e:expr) => { ... };
}Annotates an io::Error with the crate, file, and line number where the annotation has been performed.